module.exports = defineTest({
	description: 'supports optional chaining with namespace objects',
	expectedWarnings: ['MISSING_EXPORT']
});
